"""
Luxin - Interactive HTML tables with drill-down capabilities for exploring aggregated data.
"""

from luxin.tracked_df import TrackedDataFrame
from luxin.drill_table import create_drill_table

__version__ = "0.1.0"
__all__ = ["TrackedDataFrame", "create_drill_table"]

